package com.zd.laboratory.service.impl;

import java.util.List;

import com.zd.common.core.domain.per.PerPrefix;
import com.zd.common.core.utils.DateUtils;
import com.zd.common.core.utils.SecurityUtils;
import com.zd.common.datascope.annotation.DataScope;
import com.zd.common.security.utils.SaveUtil;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.zd.laboratory.mapper.LabMoldMapper;
import com.zd.laboratory.domain.LabMold;
import com.zd.laboratory.service.ILabMoldService;

/**
 * 实验室类型Service业务层处理
 *
 * @author liubo
 * @date 2022-05-17
 */
@Service
public class LabMoldServiceImpl implements ILabMoldService {
    @Autowired
    private LabMoldMapper labMoldMapper;

    /**
     * 查询实验室类型
     *
     * @param id 实验室类型主键
     * @return 实验室类型
     */
    @Override
    public LabMold selectLabMoldById(Long id) {
        return labMoldMapper.selectLabMoldById(id);
    }

    /**
     * 查询实验室类型列表
     *
     * @param labMold 实验室类型
     * @return 实验室类型
     */
    @Override
    @DataScope(permi = PerPrefix.LABORATORY_CLASSTYPE, deptAlias = "t", userAlias = "t")
    public List<LabMold> selectLabMoldList(LabMold labMold) {
        return labMoldMapper.selectLabMoldList(labMold);
    }

    /**
     * 新增实验室类型
     *
     * @param labMold 实验室类型
     * @return 结果
     */
    @Override
    public int insertLabMold(LabMold labMold) {
        //设置其他公共字段
        SaveUtil.setCommonAttr(labMold);
        return labMoldMapper.insertLabMold(labMold);
    }

    /**
     * 修改实验室类型
     *
     * @param labMold 实验室类型
     * @return 结果
     */
    @Override
    public int updateLabMold(LabMold labMold) {
        labMold.setUpdateTime(DateUtils.getNowDate());
        labMold.setUpdateBy(SecurityUtils.getUsername());
        return labMoldMapper.updateLabMold(labMold);
    }

    /**
     * 批量删除实验室类型
     *
     * @param ids 需要删除的实验室类型主键
     * @return 结果
     */
    @Override
    public int deleteLabMoldByIds(Long[] ids) {
        return labMoldMapper.deleteLabMoldByIds(ids);
    }

    /**
     * 删除实验室类型信息
     *
     * @param id 实验室类型主键
     * @return 结果
     */
    @Override
    public int deleteLabMoldById(Long id) {
        return labMoldMapper.deleteLabMoldById(id);
    }
}
